################################################################################
# BSD 2-Clause License
# 
# Copyright (c) 2021, Knott Eye
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
# 
# 1. Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation
#    and/or other materials provided with the distribution.
# 
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
# DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
################################################################################
import os, time, platform
from ctypes import cdll, util

#try:
#    if os.name == 'posix':
#        libc = cdll.LoadLibrary("libc.so.6")
#    elif os.name == 'nt':
#        libc = cdll.kernel32
#except:
#    libc = None
try:
    if platform.system() == "Windows":
        libc_path = util.find_library("msvcrt")
    else:
        libc_path = util.find_library("c")
    libc = cdll.LoadLibrary(libc_path)
    print("Loaded libc from "+libc_path)
except:
    libc_path = None
    libc = None

def posixsleep(t):
    libc.usleep(int(t * 1000000))

def ntsleep(t):
    libc.Sleep(int(t * 1000))

if libc_path == 'libc.so.6':
    sleep = posixsleep
elif libc_path == 'kernel32':
    sleep = ntsleep
elif libc_path == "libSystem.dylib":
    sleep = posixsleep
else:
    print("Couldn't figure out how to use native sleep calls with "+str(libc_path)+", event loop performance may suffer.")
    sleep = time.sleep